@@ -1,5 +1,4 @@
 import { css } from '@emotion/css';
-import { t, Trans } from '@lingui/macro';
 import React, { PureComponent } from 'react';
 
 import { FeatureState, SelectableValue } from '@grafana/data';
@@ -10,87 +9,53 @@ import {
   Field,
   FieldSet,
   Form,
-  Icon,
   Label,
   RadioButtonGroup,
   Select,
   stylesFactory,
   TimeZonePicker,
-  Tooltip,
   WeekStartPicker,
   FeatureBadge,
 } from '@grafana/ui';
-import { ENGLISH_US, FRENCH_FRANCE, SPANISH_SPAIN } from 'app/core/internationalization/constants';
+import { DashboardPicker } from 'app/core/components/Select/DashboardPicker';
+import { t, Trans } from 'app/core/internationalization';
+import { LOCALES } from 'app/core/internationalization/constants';
 import { PreferencesService } from 'app/core/services/PreferencesService';
-import { backendSrv } from 'app/core/services/backend_srv';
-import { DashboardSearchItem, DashboardSearchItemType } from 'app/features/search/types';
-
-import { UserPreferencesDTO } from '../../../types';
+import { UserPreferencesDTO } from 'app/types';
 
 export interface Props {
   resourceUri: string;
   disabled?: boolean;
+  onConfirm?: () => Promise<boolean>;
 }
 
-export type State = UserPreferencesDTO & {
-  dashboards: DashboardSearchItem[];
-};
+export type State = UserPreferencesDTO;
 
 const themes: SelectableValue[] = [
-  { value: '', label: t({ id: 'shared-preferences.theme.default-label', message: 'Default' }) },
-  { value: 'dark', label: t({ id: 'shared-preferences.theme.dark-label', message: 'Dark' }) },
-  { value: 'light', label: t({ id: 'shared-preferences.theme.light-label', message: 'Light' }) },
+  { value: '', label: t('shared-preferences.theme.default-label', 'Default') },
+  { value: 'dark', label: t('shared-preferences.theme.dark-label', 'Dark') },
+  { value: 'light', label: t('shared-preferences.theme.light-label', 'Light') },
 ];
 
-const languages: Array<SelectableValue<string>> = [
-  {
-    value: '',
-    label: t({
-      id: 'common.locale.default',
-      message: 'Default',
-    }),
-  },
-  {
-    value: ENGLISH_US,
-    label: t({
-      id: 'common.locale.en',
-      message: 'English',
-    }),
-  },
-  {
-    value: SPANISH_SPAIN,
-    label: t({
-      id: 'common.locale.es',
-      message: 'Spanish',
-    }),
-  },
-  {
-    value: FRENCH_FRANCE,
-    label: t({
-      id: 'common.locale.fr',
-      message: 'French',
-    }),
-  },
-];
+function getLanguageOptions(): Array<SelectableValue<string>> {
+  const languageOptions = LOCALES.map((v) => ({
+    value: v.code,
+    label: v.name,
+  }));
+
+  const options = [
+    {
+      value: '',
+      label: t('common.locale.default', 'Default'),
+    },
+    ...languageOptions,
+  ];
+
+  return options;
+}
 
 const i18nFlag = Boolean(config.featureToggles.internationalization);
 
-const DEFAULT_DASHBOARD_HOME: DashboardSearchItem = {
-  title: 'Default',
-  tags: [],
-  type: '' as DashboardSearchItemType,
-  uid: undefined,
-  uri: '',
-  url: '',
-  folderId: 0,
-  folderTitle: '',
-  folderUid: '',
-  folderUrl: '',
-  isStarred: false,
-  slug: '',
-  items: [],
-};
-
 export class SharedPreferences extends PureComponent<Props, State> {
   service: PreferencesService;
 
@@ -99,27 +64,16 @@ export class SharedPreferences extends PureComponent<Props, State> {
 
     this.service = new PreferencesService(props.resourceUri);
     this.state = {
-      homeDashboardUID: DEFAULT_DASHBOARD_HOME.uid,
       theme: '',
       timezone: '',
       weekStart: '',
       locale: '',
-      dashboards: [],
       queryHistory: { homeTab: '' },
     };
   }
 
   async componentDidMount() {
     const prefs = await this.service.load();
-    const dashboards = await backendSrv.search({ starred: true });
-
-    if (prefs.homeDashboardUID && !dashboards.find((d) => d.uid === prefs.homeDashboardUID)) {
-      const missingDash = await backendSrv.search({ dashboardUIDs: prefs.homeDashboardUID });
-
-      if (missingDash.length > 0) {
-        dashboards.push(missingDash[0]);
-      }
-    }
 
     this.setState({
       homeDashboardUID: prefs.homeDashboardUID,
@@ -127,15 +81,18 @@ export class SharedPreferences extends PureComponent<Props, State> {
       timezone: prefs.timezone,
       weekStart: prefs.weekStart,
       locale: prefs.locale,
-      dashboards: [DEFAULT_DASHBOARD_HOME, ...dashboards],
       queryHistory: prefs.queryHistory,
     });
   }
 
   onSubmitForm = async () => {
-    const { homeDashboardUID, theme, timezone, weekStart, locale, queryHistory } = this.state;
-    await this.service.update({ homeDashboardUID, theme, timezone, weekStart, locale, queryHistory });
-    window.location.reload();
+    const confirmationResult = this.props.onConfirm ? await this.props.onConfirm() : true;
+
+    if (confirmationResult) {
+      const { homeDashboardUID, theme, timezone, weekStart, locale, queryHistory } = this.state;
+      await this.service.update({ homeDashboardUID, theme, timezone, weekStart, locale, queryHistory });
+      window.location.reload();
+    }
   };
 
   onThemeChanged = (value: string) => {
@@ -161,36 +118,18 @@ export class SharedPreferences extends PureComponent<Props, State> {
     this.setState({ locale });
   };
 
-  getFullDashName = (dashboard: SelectableValue<DashboardSearchItem>) => {
-    if (typeof dashboard.folderTitle === 'undefined' || dashboard.folderTitle === '') {
-      return dashboard.title;
-    }
-    return dashboard.folderTitle + ' / ' + dashboard.title;
-  };
-
   render() {
-    const { theme, timezone, weekStart, homeDashboardUID, locale, dashboards } = this.state;
+    const { theme, timezone, weekStart, homeDashboardUID, locale } = this.state;
     const { disabled } = this.props;
     const styles = getStyles();
-
-    const homeDashboardTooltip = (
-      <Tooltip
-        content={
-          <Trans id="shared-preferences.fields.home-dashboard-tooltip">
-            Not finding the dashboard you want? Star it first, then it should appear in this select box.
-          </Trans>
-        }
-      >
-        <Icon name="info-circle" />
-      </Tooltip>
-    );
+    const languages = getLanguageOptions();
 
     return (
       <Form onSubmit={this.onSubmitForm}>
         {() => {
           return (
-            <FieldSet label={<Trans id="shared-preferences.title">Preferences</Trans>} disabled={disabled}>
-              <Field label={t({ id: 'shared-preferences.fields.theme-label', message: 'UI Theme' })}>
+            <FieldSet label={<Trans i18nKey="shared-preferences.title">Preferences</Trans>} disabled={disabled}>
+              <Field label={t('shared-preferences.fields.theme-label', 'UI Theme')}>
                 <RadioButtonGroup
                   options={themes}
                   value={themes.find((item) => item.value === theme)?.value}
@@ -202,32 +141,24 @@ export class SharedPreferences extends PureComponent<Props, State> {
                 label={
                   <Label htmlFor="home-dashboard-select">
                     <span className={styles.labelText}>
-                      <Trans id="shared-preferences.fields.home-dashboard-label">Home Dashboard</Trans>
+                      <Trans i18nKey="shared-preferences.fields.home-dashboard-label">Home Dashboard</Trans>
                     </span>
-
-                    {homeDashboardTooltip}
                   </Label>
                 }
                 data-testid="User preferences home dashboard drop down"
               >
-                <Select
-                  value={dashboards.find((dashboard) => dashboard.uid === homeDashboardUID)}
-                  getOptionValue={(i) => i.uid}
-                  getOptionLabel={this.getFullDashName}
-                  onChange={(dashboard: SelectableValue<DashboardSearchItem>) =>
-                    this.onHomeDashboardChanged(dashboard.uid)
-                  }
-                  options={dashboards}
-                  placeholder={t({
-                    id: 'shared-preferences.fields.home-dashboard-placeholder',
-                    message: 'Choose default dashboard',
-                  })}
+                <DashboardPicker
+                  value={homeDashboardUID}
+                  onChange={(v) => this.onHomeDashboardChanged(v?.uid ?? '')}
+                  defaultOptions={true}
+                  isClearable={true}
+                  placeholder={t('shared-preferences.fields.home-dashboard-placeholder', 'Default dashboard')}
                   inputId="home-dashboard-select"
                 />
               </Field>
 
               <Field
-                label={t({ id: 'shared-dashboard.fields.timezone-label', message: 'Timezone' })}
+                label={t('shared-dashboard.fields.timezone-label', 'Timezone')}
                 data-testid={selectors.components.TimeZonePicker.containerV2}
               >
                 <TimeZonePicker
@@ -239,7 +170,7 @@ export class SharedPreferences extends PureComponent<Props, State> {
               </Field>
 
               <Field
-                label={t({ id: 'shared-preferences.fields.week-start-label', message: 'Week start' })}
+                label={t('shared-preferences.fields.week-start-label', 'Week start')}
                 data-testid={selectors.components.WeekStartPicker.containerV2}
               >
                 <WeekStartPicker
@@ -254,9 +185,9 @@ export class SharedPreferences extends PureComponent<Props, State> {
                   label={
                     <Label htmlFor="locale-select">
                       <span className={styles.labelText}>
-                        <Trans id="shared-preferences.fields.locale-label">Language</Trans>
+                        <Trans i18nKey="shared-preferences.fields.locale-label">Language</Trans>
                       </span>
-                      <FeatureBadge featureState={FeatureState.alpha} />
+                      <FeatureBadge featureState={FeatureState.beta} />
                     </Label>
                   }
                   data-testid="User preferences language drop down"
@@ -265,10 +196,7 @@ export class SharedPreferences extends PureComponent<Props, State> {
                     value={languages.find((lang) => lang.value === locale)}
                     onChange={(locale: SelectableValue<string>) => this.onLocaleChanged(locale.value ?? '')}
                     options={languages}
-                    placeholder={t({
-                      id: 'shared-preferences.fields.locale-placeholder',
-                      message: 'Choose language',
-                    })}
+                    placeholder={t('shared-preferences.fields.locale-placeholder', 'Choose language')}
                     inputId="locale-select"
                   />
                 </Field>
@@ -280,7 +208,7 @@ export class SharedPreferences extends PureComponent<Props, State> {
                   variant="primary"
                   data-testid={selectors.components.UserProfile.preferencesSaveButton}
                 >
-                  <Trans id="common.save">Save</Trans>
+                  <Trans i18nKey="common.save">Save</Trans>
                 </Button>
               </div>
             </FieldSet>
