@@ -316,7 +316,7 @@ export const CreateRecordedQueryUnconnected = ({ query, queries, dataSource, var
                               }
                             }}
                             variable={variable}
-                            readOnly={true}
+                            readOnly={false}
                           />
                         </InlineField>
                       );
