@@ -4,6 +4,7 @@ import { connect, ConnectedProps } from 'react-redux';
 
 import { applyFieldOverrides, PanelData, dateTimeFormat, toCSV, LoadingState } from '@grafana/data';
 import { config } from '@grafana/runtime';
+import { GrafanaContext } from 'app/core/context/GrafanaContext';
 import { GrafanaRouteComponentProps } from 'app/core/navigation/types';
 import { SoloPanel } from 'app/features/dashboard/containers/SoloPanelPage';
 import { PanelModel, DashboardModel } from 'app/features/dashboard/state';
@@ -16,7 +17,8 @@ export interface DashboardPageRouteParams {
   slug?: string;
 }
 
-export interface OwnProps extends GrafanaRouteComponentProps<DashboardPageRouteParams, { panelId?: string }> {
+export interface OwnProps
+  extends GrafanaRouteComponentProps<DashboardPageRouteParams, { panelId?: string; timezone?: string }> {
   dashboard: DashboardModel | null;
 }
 
@@ -37,6 +39,8 @@ const connector = connect(mapStateToProps, mapDispatchToProps);
 export type Props = ConnectedProps<typeof connector> & OwnProps;
 
 export class CSVExportPage extends Component<Props, State> {
+  static contextType = GrafanaContext;
+
   state: State = {
     panel: null,
     notFound: false,
@@ -51,6 +55,7 @@ export class CSVExportPage extends Component<Props, State> {
       urlType: match.params.type,
       routeName: route.routeName,
       fixUrl: false,
+      keybindingSrv: this.context.keybindings,
     });
   }
 
@@ -95,6 +100,8 @@ export class CSVExportPage extends Component<Props, State> {
     const data = panelData.series;
     // We need to apply field config even though it was already applied in the PanelQueryRunner.
     // That's because transformers create new fields and data frames, so i.e. display processor is no longer there
+
+    const timeZone = this.props.queryParams.timezone || dashboard?.timezone;
     const dataFrames = applyFieldOverrides({
       data,
       theme: config.theme2,
@@ -102,7 +109,7 @@ export class CSVExportPage extends Component<Props, State> {
       replaceVariables: (value: string) => {
         return value;
       },
-      timeZone: dashboard?.timezone,
+      timeZone: timeZone,
     });
 
     const dataFrameCsv = toCSV([dataFrames[0]], {});
@@ -121,6 +128,7 @@ export class CSVExportPage extends Component<Props, State> {
         notFound={this.state.notFound}
         panel={this.state.panel}
         panelId={this.getPanelId()}
+        timezone={this.props.queryParams.timezone}
       />
     );
   }
