@@ -1,8 +1,8 @@
 import { css } from '@emotion/css';
-import React from 'react';
+import React, { useEffect } from 'react';
 
 import { GrafanaTheme2, urlUtil } from '@grafana/data';
-import { featureEnabled } from '@grafana/runtime';
+import { featureEnabled, reportInteraction } from '@grafana/runtime';
 import { LinkButton, useStyles2 } from '@grafana/ui';
 import { UpgradeBox, UpgradeContentVertical } from 'app/core/components/Upgrade/UpgradeBox';
 import { highlightTrial } from 'app/features/admin/utils';
@@ -11,6 +11,9 @@ import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 import { getVariablesUrlParams } from 'app/features/variables/getAllVariableValuesForUrl';
 
 export const CreateReportTab = ({ dashboard, onDismiss }: ShareModalTabProps) => {
+  useEffect(() => {
+    reportInteraction('grafana_dashboards_report_share_viewed');
+  }, []);
   const styles = useStyles2(getStyles);
   const getUrl = () => {
     const variablesQuery = urlUtil.toUrlParams(getVariablesUrlParams());
