@@ -50,7 +50,11 @@ const ReportBranding: FC<Props> = ({ settings, register, control, watch, errors
             type="url"
           />
         </Field>
-        <ImagePreview url={(watchReportLogo || defaultReportLogo) as string} width="60px" />
+        <ImagePreview
+          url={(watchReportLogo || defaultReportLogo) as string}
+          width="60px"
+          altText="Company logo preview"
+        />
       </FieldSet>
 
       <FieldSet label="Email branding" disabled={!canEditSettings}>
@@ -71,7 +75,7 @@ const ReportBranding: FC<Props> = ({ settings, register, control, watch, errors
             type="url"
           />
         </Field>
-        <ImagePreview url={(watchEmailLogo || defaultEmailLogo) as string} />
+        <ImagePreview url={(watchEmailLogo || defaultEmailLogo) as string} altText="Company logo preview" />
         <Field label="Email footer">
           <InputControl
             defaultValue={emailFooterMode || FooterMode.SentBy}
