@@ -39,13 +39,13 @@ export const ReportsSettingsPage = ({ navModel }: Props) => {
   };
 
   if (error) {
-    return <ErrorPage navModel={navModel} />;
+    return <ErrorPage />;
   }
 
   const canEditSettings = contextSrv.hasPermission(AccessControlAction.ReportingSettingsWrite);
 
   return (
-    <Page navModel={navModel}>
+    <Page navId="reports-settings" subTitle="Manage report template settings.">
       <Page.Contents isLoading={loading}>
         {!config.rendererAvailable ? (
           <NoRendererInfoBox variant="error" />
