@@ -5,6 +5,8 @@ import { DataSourceInstanceSettings, toUtc } from '@grafana/data';
 import { FetchResponse } from '@grafana/runtime';
 import { backendSrv } from 'app/core/services/backend_srv'; // will use the version in __mocks__
 
+import { PromApplication } from '../../../types/unified-alerting-dto';
+
 import { PrometheusDatasource } from './datasource';
 import PrometheusMetricFindQuery from './metric_find_query';
 import { PromOptions } from './types';
@@ -23,7 +25,7 @@ const instanceSettings = {
   user: 'test',
   password: 'mupp',
   jsonData: { httpMethod: 'GET' },
-} as unknown as DataSourceInstanceSettings<PromOptions>;
+} as Partial<DataSourceInstanceSettings<PromOptions>> as DataSourceInstanceSettings<PromOptions>;
 const raw = {
   from: toUtc('2018-04-25 10:00'),
   to: toUtc('2018-04-25 11:00'),
@@ -52,14 +54,22 @@ beforeEach(() => {
 });
 
 describe('PrometheusMetricFindQuery', () => {
-  let ds: PrometheusDatasource;
+  let legacyPrometheusDatasource: PrometheusDatasource;
+  let prometheusDatasource: PrometheusDatasource;
   beforeEach(() => {
-    ds = new PrometheusDatasource(instanceSettings, templateSrvStub);
+    legacyPrometheusDatasource = new PrometheusDatasource(instanceSettings, templateSrvStub);
+    prometheusDatasource = new PrometheusDatasource(
+      {
+        ...instanceSettings,
+        jsonData: { ...instanceSettings.jsonData, prometheusVersion: '2.2.0', prometheusType: PromApplication.Mimir },
+      },
+      templateSrvStub
+    );
   });
 
-  const setupMetricFindQuery = (data: any) => {
+  const setupMetricFindQuery = (data: any, datasource?: PrometheusDatasource) => {
     fetchMock.mockImplementation(() => of({ status: 'success', data: data.response } as unknown as FetchResponse));
-    return new PrometheusMetricFindQuery(ds, data.query);
+    return new PrometheusMetricFindQuery(datasource ?? legacyPrometheusDatasource, data.query);
   };
 
   describe('When performing metricFindQuery', () => {
@@ -102,6 +112,7 @@ describe('PrometheusMetricFindQuery', () => {
       });
     });
 
+    // <LegacyPrometheus>
     it('label_values(metric, resource) should generate series query with correct time', async () => {
       const query = setupMetricFindQuery({
         query: 'label_values(metric, resource)',
@@ -179,6 +190,7 @@ describe('PrometheusMetricFindQuery', () => {
         headers: {},
       });
     });
+    // </LegacyPrometheus>
 
     it('metrics(metric.*) should generate metric name query', async () => {
       const query = setupMetricFindQuery({
@@ -221,7 +233,7 @@ describe('PrometheusMetricFindQuery', () => {
       expect(fetchMock).toHaveBeenCalledTimes(1);
       expect(fetchMock).toHaveBeenCalledWith({
         method: 'GET',
-        url: `proxied/api/v1/query?query=metric&time=${raw.to.unix()}`,
+        url: `/api/datasources/1/resources/api/v1/query?query=metric&time=${raw.to.unix()}`,
         requestId: undefined,
         headers: {},
       });
@@ -243,7 +255,7 @@ describe('PrometheusMetricFindQuery', () => {
       expect(fetchMock).toHaveBeenCalledTimes(1);
       expect(fetchMock).toHaveBeenCalledWith({
         method: 'GET',
-        url: `proxied/api/v1/query?query=1%2B1&time=${raw.to.unix()}`,
+        url: `/api/datasources/1/resources/api/v1/query?query=1%2B1&time=${raw.to.unix()}`,
         requestId: undefined,
         headers: {},
       });
@@ -277,5 +289,63 @@ describe('PrometheusMetricFindQuery', () => {
         headers: {},
       });
     });
+
+    // <ModernPrometheus>
+    it('label_values(metric, resource) should generate label values query with correct time', async () => {
+      const metricName = 'metricName';
+      const resourceName = 'resourceName';
+      const query = setupMetricFindQuery(
+        {
+          query: `label_values(${metricName}, ${resourceName})`,
+          response: {
+            data: [
+              { __name__: `${metricName}`, resourceName: 'value1' },
+              { __name__: `${metricName}`, resourceName: 'value2' },
+              { __name__: `${metricName}`, resourceName: 'value3' },
+            ],
+          },
+        },
+        prometheusDatasource
+      );
+      const results = await query.process();
+
+      expect(results).toHaveLength(3);
+      expect(fetchMock).toHaveBeenCalledTimes(1);
+      expect(fetchMock).toHaveBeenCalledWith({
+        method: 'GET',
+        url: `/api/datasources/1/resources/api/v1/label/${resourceName}/values?match${encodeURIComponent(
+          '[]'
+        )}=${metricName}&start=${raw.from.unix()}&end=${raw.to.unix()}`,
+        hideFromInspector: true,
+        headers: {},
+      });
+    });
+
+    it('label_values(metric{label1="foo", label2="bar", label3="baz"}, resource) should generate label values query with correct time', async () => {
+      const metricName = 'metricName';
+      const resourceName = 'resourceName';
+      const label1Name = 'label1';
+      const label1Value = 'label1Value';
+      const query = setupMetricFindQuery(
+        {
+          query: `label_values(${metricName}{${label1Name}="${label1Value}"}, ${resourceName})`,
+          response: {
+            data: [{ __name__: metricName, resourceName: label1Value }],
+          },
+        },
+        prometheusDatasource
+      );
+      const results = await query.process();
+
+      expect(results).toHaveLength(1);
+      expect(fetchMock).toHaveBeenCalledTimes(1);
+      expect(fetchMock).toHaveBeenCalledWith({
+        method: 'GET',
+        url: `/api/datasources/1/resources/api/v1/label/${resourceName}/values?match%5B%5D=${metricName}%7B${label1Name}%3D%22${label1Value}%22%7D&start=1524650400&end=1524654000`,
+        hideFromInspector: true,
+        headers: {},
+      });
+    });
+    // </ ModernPrometheus>
   });
 });
