@@ -2,15 +2,25 @@ import { getByText, render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 import React from 'react';
 
-import { LoadingState, MutableDataFrame, PanelData, TimeRange } from '@grafana/data';
+import {
+  DataSourceInstanceSettings,
+  DataSourcePluginMeta,
+  LoadingState,
+  MutableDataFrame,
+  PanelData,
+  TimeRange,
+} from '@grafana/data';
 
+import { PromApplication } from '../../../../../types/unified-alerting-dto';
 import { PrometheusDatasource } from '../../datasource';
 import PromQlLanguageProvider from '../../language_provider';
 import { EmptyLanguageProviderMock } from '../../language_provider.mock';
+import { PromOptions } from '../../types';
 import { getLabelSelects } from '../testUtils';
 import { PromVisualQuery } from '../types';
 
 import { PromQueryBuilder } from './PromQueryBuilder';
+import { EXPLAIN_LABEL_FILTER_CONTENT } from './PromQueryBuilderExplained';
 
 const defaultQuery: PromVisualQuery = {
   metric: 'random_metric',
@@ -93,6 +103,7 @@ describe('PromQueryBuilder', () => {
     await waitFor(() => expect(datasource.getVariables).toBeCalled());
   });
 
+  // <LegacyPrometheus>
   it('tries to load labels when metric selected', async () => {
     const { languageProvider } = setup();
     await openLabelNameSelect();
@@ -119,6 +130,7 @@ describe('PromQueryBuilder', () => {
       expect(languageProvider.fetchSeriesLabels).toBeCalledWith('{label_name="label_value", __name__="random_metric"}')
     );
   });
+  //</LegacyPrometheus>
 
   it('tries to load labels when metric is not selected', async () => {
     const { languageProvider } = setup({
@@ -183,28 +195,113 @@ describe('PromQueryBuilder', () => {
     await userEvent.click(screen.getByText('histogram_metric_sum'));
     await waitFor(() => expect(screen.getAllByText(/hint:/)).toHaveLength(2));
   });
+
+  it('shows explain section when showExplain is true', async () => {
+    const { datasource } = createDatasource();
+    const props = createProps(datasource);
+    props.showExplain = true;
+    render(
+      <PromQueryBuilder
+        {...props}
+        query={{
+          metric: 'histogram_metric_sum',
+          labels: [],
+          operations: [],
+        }}
+      />
+    );
+    expect(await screen.findByText(EXPLAIN_LABEL_FILTER_CONTENT)).toBeInTheDocument();
+  });
+
+  it('does not show explain section when showExplain is false', async () => {
+    const { datasource } = createDatasource();
+    const props = createProps(datasource);
+    render(
+      <PromQueryBuilder
+        {...props}
+        query={{
+          metric: 'histogram_metric_sum',
+          labels: [],
+          operations: [],
+        }}
+      />
+    );
+    expect(await screen.queryByText(EXPLAIN_LABEL_FILTER_CONTENT)).not.toBeInTheDocument();
+  });
+
+  // <ModernPrometheus>
+  it('tries to load labels when metric selected modern prom', async () => {
+    const { languageProvider } = setup(undefined, undefined, {
+      jsonData: { prometheusVersion: '2.38.1', prometheusType: PromApplication.Prometheus },
+    });
+    await openLabelNameSelect();
+    await waitFor(() => expect(languageProvider.fetchSeriesLabelsMatch).toBeCalledWith('{__name__="random_metric"}'));
+  });
+
+  it('tries to load variables in label field modern prom', async () => {
+    const { datasource } = setup(undefined, undefined, {
+      jsonData: { prometheusVersion: '2.38.1', prometheusType: PromApplication.Prometheus },
+    });
+    datasource.getVariables = jest.fn().mockReturnValue([]);
+    await openLabelNameSelect();
+    await waitFor(() => expect(datasource.getVariables).toBeCalled());
+  });
+
+  it('tries to load labels when metric selected and other labels are already present modern prom', async () => {
+    const { languageProvider } = setup(
+      {
+        ...defaultQuery,
+        labels: [
+          { label: 'label_name', op: '=', value: 'label_value' },
+          { label: 'foo', op: '=', value: 'bar' },
+        ],
+      },
+      undefined,
+      { jsonData: { prometheusVersion: '2.38.1', prometheusType: PromApplication.Prometheus } }
+    );
+    await openLabelNameSelect(1);
+    await waitFor(() =>
+      expect(languageProvider.fetchSeriesLabelsMatch).toBeCalledWith(
+        '{label_name="label_value", __name__="random_metric"}'
+      )
+    );
+  });
+  //</ModernPrometheus>
 });
 
-function setup(query: PromVisualQuery = defaultQuery, data?: PanelData) {
+function createDatasource(options?: Partial<DataSourceInstanceSettings<PromOptions>>) {
   const languageProvider = new EmptyLanguageProviderMock() as unknown as PromQlLanguageProvider;
   const datasource = new PrometheusDatasource(
     {
       url: '',
       jsonData: {},
-      meta: {} as any,
-    } as any,
+      meta: {} as DataSourcePluginMeta,
+      ...options,
+    } as DataSourceInstanceSettings<PromOptions>,
     undefined,
     undefined,
     languageProvider
   );
-  const props = {
+  return { datasource, languageProvider };
+}
+
+function createProps(datasource: PrometheusDatasource, data?: PanelData) {
+  return {
     datasource,
     onRunQuery: () => {},
     onChange: () => {},
     data,
     showExplain: false,
   };
+}
 
+function setup(
+  query: PromVisualQuery = defaultQuery,
+  data?: PanelData,
+  datasourceOptionsOverride?: Partial<DataSourceInstanceSettings<PromOptions>>
+) {
+  const { datasource, languageProvider } = createDatasource(datasourceOptionsOverride);
+  const props = createProps(datasource, data);
   const { container } = render(<PromQueryBuilder {...props} query={query} />);
   return { languageProvider, datasource, container };
 }
