@@ -35,8 +35,7 @@ import {
 import { applyNullInsertThreshold } from '@grafana/ui/src/components/GraphNG/nullInsertThreshold';
 import { nullToValue } from '@grafana/ui/src/components/GraphNG/nullToValue';
 import { PlotTooltipInterpolator } from '@grafana/ui/src/components/uPlot/types';
-
-import { preparePlotData2, getStackingGroups } from '../../../../../packages/grafana-ui/src/components/uPlot/utils';
+import { preparePlotData2, getStackingGroups } from '@grafana/ui/src/components/uPlot/utils';
 
 import { getConfig, TimelineCoreOptions } from './timeline';
 import { TimelineFieldConfig, TimelineOptions } from './types';
@@ -480,10 +479,21 @@ export function getThresholdItems(fieldConfig: FieldConfig, theme: GrafanaTheme2
 
   const fmt = (v: number) => formattedValueToString(disp(v));
 
-  for (let i = 1; i <= steps.length; i++) {
-    const step = steps[i - 1];
+  for (let i = 0; i < steps.length; i++) {
+    let step = steps[i];
+    let value = step.value;
+    let pre = '';
+    let suf = '';
+
+    if (value === -Infinity && i < steps.length - 1) {
+      value = steps[i + 1].value;
+      pre = '< ';
+    } else {
+      suf = '+';
+    }
+
     items.push({
-      label: i === 1 ? `< ${fmt(step.value)}` : `${fmt(step.value)}+`,
+      label: `${pre}${fmt(value)}${suf}`,
       color: theme.visualization.getColorByName(step.color),
       yAxis: 1,
     });
